# Install and start GAMS Engine

- Install Docker from `https://docs.docker.com/engine/install/`
- On Linux: Install Docker Compose from `https://docs.docker.com/compose/install/`
- Extract `gams_engine.zip` file into a folder
- Open a terminal and `cd` into that folder and `./up.sh` (with admin privileges). The following options are available
  - `-w` Number of GAMS workers to use
  - `-p` Port GAMS Engine should listen on
  - `-c` Path to certificate file
  - `-k` Path to certificate key file

## Access to GAMS Engine

Once the script is finished, GAMS Engine should be running.
Depending on whether an SSL or an unencrypted setup has been selected,
Engine and Engine UI can be reached via:
- SSL setup: Open `http(s)://mydomain.com` in your browser (replace mydomain with your URL)
- Unencrypted setup: Engine runs on the port you selected before (default is port 80).
  Open `http://192.168.178.184:80` in your browser (replace IP and port accordingly)
- This will open the Engine UI
  - Default username: admin
  - Default password: admin
  - We strongly recommend to change the default password (upper left corner)

For further documentation, please refer to `https://www.gams.com/engine/`
Do not hesitate to contact us if you have any questions!

## Licenses

For a GAMS Engine setup, both a tailored GAMS license and an Engine license are required.
The license keys can be entered directly in the Engine UI. Login as admin user. Under
`Users` click on `Update Engine license` and paste your license key. Do the same for the
GAMS license (button `Update GAMS license`). A GAMS license can be provided system-wide
or user-specific. For more information about this, please refer to
`https://www.gams.com/engine#license`

## Stop GAMS Engine

To stop Engine, call `docker compose down`. If you like to delete all your data, you can
call `docker compose down -v`.

## I want to add some features to GAMS Workers

If out-of-the-box GAMS Worker is not enough for your needs, you can extend them. Please,
refer to tutorial in `extending_worker/how_to.md`.

## System-wide GAMS arguments

You can supply GAMS arguments that are appended for each job. For that you can add
`GMS_RUNNER_WORKER_SYS_ARGS` environment variable to worker.

For example, if you add `GMS_RUNNER_WORKER_SYS_ARGS: "mip=cplex"`, it will add `mip=cplex`
argument to each GAMS run. System-wide arguments are appended after model arguments. So
if you provided `mip=cbc` in the model, `mip=cplex` would be appended later and it would
take precedence and GAMS would use `cplex`. You can experiment with the argument ordering
in your local machine and Worker will behave similar.

Worker part of your `docker-compose.yml` file would like:

```
  worker:
    image: gams/engine-worker:latest
    restart: unless-stopped
    environment:
      GMS_RUNNER_WORKER_SYS_ARGS: "mip=cplex"
      GMS_RUNNER_DATABASE_SERVER: database
    ...
```

To add more than one argument separate them with comma.

```
  worker:
    image: gams/engine-worker:latest
    restart: unless-stopped
    environment:
      GMS_RUNNER_WORKER_SYS_ARGS: "mip=cplex,limrow=0,limcol=0"
      GMS_RUNNER_DATABASE_SERVER: database
    ...
```
